%main.m  -Andy Ruina  Feb 13, 2019
%Driver for ODE solns

clear  % A good habit to put this at the top.  Helps debugging. 

% This calls an ODE solver which calls a rhs function
% General Setup
tend = 20;                           %  Ending time "t end"
npointspers = 10;                    %  number of h intervals per time unit
ntimes      = tend * npointspers + 1; %  total number of time points
tarray = linspace(0, tend, ntimes);   %  All of the times soln is output

%Pretty general multi-DoF vibrations problem
p.K= [ 3  -1;  -1 3]; % Make the stiffness matrix (generally symmetric)
p.C = [ 0 0; 0 0];    % The damping matrix (generally symmetric)
p.M = [ 1 0; 0 2];    % The mass matrix (diagonal in this course)
p.F0= [ 0 0]';  p.omega = 17;   %Forcing shape and frequency
%For linear algebra pros: M is positive definite; C & K are positive semi-definite

%%%%%%%%%%%%%
% Finding normal modes
A = p.M^(-1)*p.K;   % The main matrix, can also write as  M\K
[V,D]=eig(A)        % Cols of V are e-vectors; diagonals of D are e-values
%%%%%%%%%%%%%

% Normal modes:  x0= [ 1 1]'   and x0 = [1 -1]', released from rest
%x0 = [1  1]'; v0 = [0 0]';     % ICs, whatever pleases you
x0 = V(:,2);  v0 = [0 0]';      % A normal mode
z0 = [x0;v0];                   % ICs, packed into a column vector

% Next  line gets the solution to the ODES
% Choice of two methods, Euler or Midpoint (2nd order RK)
%[tarray zarray]  = myEulerSolver%(@my2DoFrhs, tarray, z0, p);
[tarray zarray]   = myMidpointSolver(@Viberhs, tarray, z0, p);

t= tarray;
x1 = zarray(:,1); x2 = zarray(:,2);   % Extract the two columns of zarray
plot (t,x1,t,x2); shg                 % Plot x1 vs t and x2 vs t
ylabel('$x_1, x_2$','interpreter','latex'); %Nice looking math
xlabel('$t$','Interpreter','latex'); 
title(['Two mass system. -A. Ruina   ' datestr(now)])

